Page 163 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 163

Home

    offering a solution. The supposed crisis is man's
    destruction of the environment. The proposed solution is
    total control of the planet by the United Nations.

    A giant step in this direction began in June of 1992,
    when between 20,000 to 30,000 participants from 178
    nations attended the United Nations Conference on

    Environment and Development (UNCED) in Rio de
    Janeiro, Brazil. The overall goal of the conference was to
    "Save the Planet."

    By what means they intend to do this was pointed out
    by the late Dixy Lee Ray, former member of the Atomic
    Energy Commission, assistant secretary of state in the U.
    S. Bureau of Oceans, and long-time member of the
    zoology faculty at the University of Washington. In her
    book Environmental Overkill: Whatever Happened To

    The objective, clearly enunciated by the leaders of
    UNCED, is to bring about a change in the present
    system of independent nations. The future is to be world
    government, with central planning by the UN. Fear of
    environmental crises, whether real or not, is expected to
    lead to compliance. If force is needed, it will be provided
    by a UN green-helmeted police force, already authorized
    by the Security Council.°

    Change Treaty which was signed by President Bush and
    ratified by the U. S. Senate on October 15, 1992. This
    United Nations treaty, moving us closer to world

    158

    The Secret Side of History

    Common Sense? she stated:

    Out of this conference came the Global Climate